@@ -6,3 +6,7 @@ streamds -h
 streamds list
 
 streamds get detectors
+
+streamds help detectors
+
+streamds help foo
