@@ -78,7 +78,7 @@ class StreamDS:
 
     def print_streams(self):
         """Print the documentation for all available streams."""
-        for stream in self.streams.values():
+        for stream in sorted(self.streams.values()):
             self._print_stream_parameters(stream)
 
     def _print_stream_parameters(self, stream):
@@ -91,6 +91,18 @@ class StreamDS:
         print("  optional selectors:  {}".format(stream.optional_selectors))
         print()
 
+    def help(self, stream_name):
+        """Print help for a given stream"""
+        try:
+            self._print_stream_parameters(self.streams[stream_name])
+        except KeyError:
+            log.error("There is no stream called '{}'".format(stream_name))
+            print(
+                "Available streams:\n{}".format(
+                    ", ".join(s.stream for s in sorted(self.streams.values()))
+                )
+            )
+
     def get(self, stream, fmt="txt", container=None, renamemap=None, **kwargs):
         """Retrieve the data for a given stream manually
 
